@@ -21,8 +21,8 @@ from .constants import (
     DEVICE_INFO_API_V2,
     HEATING_CIRCUIT1_API_V1,
     HEATING_CIRCUIT1_API_V2,
-    PRESET_MODE_DICT,
-    PRESET_MODE_DICT_REVERSE,
+    HVAC_MODE_DICT,
+    HVAC_MODE_DICT_REVERSE,
 )
 from .exceptions import BSBLANConnectionError, BSBLANError
 from .models import Device, Info, State
@@ -190,9 +190,7 @@ class BSBLAN:
         logger.debug("get state")
         data = await self._request(params={"Parameter": f"{self._heatingcircuit1}"})
         data = dict(zip(self._heating_params, list(data.values())))
-        data["preset_mode"]["value"] = PRESET_MODE_DICT[
-            int(data["preset_mode"]["value"])
-        ]
+        data["hvac_mode"]["value"] = HVAC_MODE_DICT[int(data["hvac_mode"]["value"])]
         return State.parse_obj(data)
 
     async def _get_dict_version(self) -> dict:
@@ -261,13 +259,13 @@ class BSBLAN:
     async def thermostat(
         self,
         target_temperature: str | None = None,
-        preset_mode: str | None = None,
+        hvac_mode: str | None = None,
     ) -> None:
         """Change the state of the thermostat through BSB-Lan.
 
         Args:
             target_temperature: Target temperature to set.
-            preset_mode: Preset mode to set.
+            hvac_mode: Preset mode to set.
 
         Raises:
             BSBLANError: The provided values are invalid.
@@ -279,7 +277,7 @@ class BSBLAN:
             """Describe state dictionary that can be set on the thermostat."""
 
             target_temperature: str
-            preset_mode: str
+            hvac_mode: str
             Parameter: str
             Value: str
             Type: str
@@ -296,11 +294,11 @@ class BSBLAN:
             state["Value"] = target_temperature
             state["Type"] = "1"
 
-        if preset_mode is not None:
-            if preset_mode not in PRESET_MODE_DICT_REVERSE:
+        if hvac_mode is not None:
+            if hvac_mode not in HVAC_MODE_DICT_REVERSE:
                 raise BSBLANError("Preset mode is not valid")
             state["Parameter"] = "700"
-            state["EnumValue"] = PRESET_MODE_DICT_REVERSE[preset_mode]
+            state["EnumValue"] = HVAC_MODE_DICT_REVERSE[hvac_mode]
             state["Type"] = "1"
 
         if not state:
